@@ -181,6 +181,8 @@ class GbpOptionParser(OptionParser):
                 'component': [],
                 'bare': 'True',
                 'urgency': 'medium',
+                'repo-user': 'DEBIAN',
+                'repo-email': 'DEBIAN',
                 }
     help = {
         'debian-branch':
@@ -350,7 +352,15 @@ class GbpOptionParser(OptionParser):
             "wether to create a bare repository on the remote side. "
             "'Default is '%(bare)s'.",
         'urgency':
-            "Set urgency level, default is '%(urgency)s'"
+            "Set urgency level, default is '%(urgency)s'",
+        'repo-user':
+            "Set repo username from the DEBFULLNAME and DEBEMAIL "
+            "environment variables ('DEBIAN') or fallback to the "
+            "git configuration ('GIT'), default is '%(repo-user)s'",
+        'repo-email':
+            "Set repo email from the DEBFULLNAME and DEBEMAIL "
+            "environment variables ('DEBIAN') or fallback to the "
+            "git configuration ('GIT'), default is '%(repo-email)s'"
     }
 
     short_opts = {
@@ -366,7 +376,7 @@ class GbpOptionParser(OptionParser):
     list_opts = ['filter', 'component']
 
     @classmethod
-    def get_config_files(klass, no_local=False):
+    def get_config_files(cls, no_local=False):
         """
         Get list of config files from the I{GBP_CONF_FILES} environment
         variable.
@@ -376,15 +386,16 @@ class GbpOptionParser(OptionParser):
         @return: list of config files we need to parse
         @rtype: C{list}
 
+        >>> import re
         >>> conf_backup = os.getenv('GBP_CONF_FILES')
         >>> if conf_backup is not None: del os.environ['GBP_CONF_FILES']
         >>> homedir = os.path.expanduser("~")
         >>> files = GbpOptionParser.get_config_files()
-        >>> files_mangled = [file.replace(homedir, 'HOME') for file in files]
+        >>> files_mangled = [re.sub("^%s" % homedir, 'HOME', file) for file in files]
         >>> sorted(files_mangled)
         ['%(git_dir)s/gbp.conf', '%(top_dir)s/.gbp.conf', '%(top_dir)s/debian/gbp.conf', '/etc/git-buildpackage/gbp.conf', 'HOME/.gbp.conf']
         >>> files = GbpOptionParser.get_config_files(no_local=True)
-        >>> files_mangled = [file.replace(homedir, 'HOME') for file in files]
+        >>> files_mangled = [re.sub("^%s" % homedir, 'HOME', file) for file in files]
         >>> sorted(files_mangled)
         ['/etc/git-buildpackage/gbp.conf', 'HOME/.gbp.conf']
         >>> os.environ['GBP_CONF_FILES'] = 'test1:test2'
@@ -394,13 +405,13 @@ class GbpOptionParser(OptionParser):
         >>> if conf_backup is not None: os.environ['GBP_CONF_FILES'] = conf_backup
         """
         envvar = os.environ.get('GBP_CONF_FILES')
-        files = envvar.split(':') if envvar else [f for (f, _) in klass.def_config_files]
+        files = envvar.split(':') if envvar else [f for (f, _) in cls.def_config_files]
         files = [os.path.expanduser(fname) for fname in files]
         if no_local:
             files = [fname for fname in files if fname.startswith('/')]
         return files
 
-    def _read_config_file(self, parser, repo, filename):
+    def _read_config_file(self, repo, filename):
         """Read config file"""
         str_fields = {}
         if repo:
@@ -416,7 +427,7 @@ class GbpOptionParser(OptionParser):
                 filename == os.path.join(repo.path, '.gbp.conf') and
                 os.path.exists(filename)):
             self._warn_old_gbp_conf(filename)
-        parser.read(filename)
+        self.config_parser.read(filename)
 
     def _warn_old_config_section(self, oldcmd, cmd):
         if not os.getenv("GBP_DISABLE_SECTION_DEPRECTATION"):
@@ -424,9 +435,16 @@ class GbpOptionParser(OptionParser):
                          "please rename to [%s]" % (oldcmd, cmd))
 
     def _warn_old_gbp_conf(self, gbp_conf):
-        if not os.getenv("GBP_DISABLE_GBP_CONF_DEPRECTATION"):
+        if (not os.getenv("GBP_DISABLE_GBP_CONF_DEPRECTATION") and
+                not self._warned_old_gbp_conf):
             gbp.log.warn("Deprecated configuration file found at %s, "
                          "check gbp.conf(5) for alternatives" % gbp_conf)
+            self._warned_old_gbp_conf = True
+
+    @property
+    def config_file_sections(self):
+        """List of all found config file sections"""
+        return self.config_parser.sections()
 
     @staticmethod
     def _listify(value):
@@ -477,11 +495,9 @@ class GbpOptionParser(OptionParser):
         Parse the possible config files and set appropriate values
         default values
         """
-        parser = configparser.SafeConfigParser()
+        parser = self.config_parser
         # Fill in the built in values
         self.config = dict(self.__class__.defaults)
-        # Update with the values from the defaults section. This is needed
-        # in case the config file doesn't have a [<command>] section at all
         config_files = self.get_config_files()
         try:
             repo = GitRepository(".")
@@ -489,7 +505,9 @@ class GbpOptionParser(OptionParser):
             repo = None
         # Read all config files
         for filename in config_files:
-            self._read_config_file(parser, repo, filename)
+            self._read_config_file(repo, filename)
+        # Update with the values from the defaults section. This is needed
+        # in case the config file doesn't have a [<command>] section at all
         self.config.update(dict(parser.defaults()))
 
         # Make sure we read any legacy sections prior to the real subcommands
@@ -541,6 +559,8 @@ class GbpOptionParser(OptionParser):
         self.prefix = prefix
         self.config = {}
         self.valid_options = []
+        self.config_parser = configparser.SafeConfigParser()
+        self._warned_old_gbp_conf = False
 
         try:
             self.parse_config_files()
@@ -726,6 +746,10 @@ class GbpOptionParserDebian(GbpOptionParser):
         'builder': 'debuild -i -I',
     })
 
+    def _warn_old_gbp_conf(self, gbp_conf):
+        if os.path.exists("debian/control"):
+            GbpOptionParser._warn_old_gbp_conf(self, gbp_conf)
+
 
 class GbpOptionParserRpm(GbpOptionParser):
     """
@@ -817,4 +841,9 @@ class GbpOptionParserRpm(GbpOptionParser):
                 "default is '%(git-author)s'",
         })
 
+    def _warn_old_gbp_conf(self, gbp_conf):
+        # The rpm based tools use $repo/.gbp.conf a lot, don't
+        # warn there yet
+        pass
+
 # vim:et:ts=4:sw=4:et:sts=4:ai:set list listchars=tab\:»·,trail\:·:
