@@ -534,12 +534,11 @@ class GitRepository(object):
         @param msg: the reason for the update
         @type msg: C{str}
         """
-        args = [ref, new]
-        if old:
-            args += [old]
-        if msg:
-            args = ['-m', msg] + args
-        self._git_command("update-ref", args)
+        args = GitArgs()
+        args.add_true(msg, '-m', msg)
+        args.add(ref, new)
+        args.add_true(old, old)
+        self._git_command("update-ref", args.args)
 
     def branch_contains(self, branch, commit, remote=False):
         """
@@ -791,25 +790,32 @@ class GitRepository(object):
             args += [commit, '--']
             self._git_command("reset", args)
 
-    def _status(self, porcelain, ignore_untracked):
+    def _status(self, porcelain, ignore_untracked, paths):
         args = GitArgs()
         args.add_true(ignore_untracked, '-uno')
         args.add_true(porcelain, '--porcelain')
 
+        if paths is None:
+            paths = []
+        elif isinstance(paths, six.string_types):
+            paths = [paths]
+
         out, ret = self._git_getoutput('status',
-                                       args.args,
+                                       args.args + paths,
                                        extra_env={'LC_ALL': 'C'})
         if ret:
             raise GitRepositoryError("Can't get repository status")
         return out
 
-    def is_clean(self, ignore_untracked=False):
+    def is_clean(self, ignore_untracked=False, paths=None):
         """
         Does the repository contain any uncommitted modifications?
 
         @param ignore_untracked: whether to ignore untracked files when
             checking the repository status
         @type ignore_untracked: C{bool}
+        @param paths: only check changes on paths
+        @type paths: C{list} of C{stings}
         @return: C{True} if the repository is clean, C{False} otherwise
             and Git's status message
         @rtype: C{tuple}
@@ -818,11 +824,13 @@ class GitRepository(object):
             return (True, '')
 
         out = self._status(porcelain=True,
-                           ignore_untracked=ignore_untracked)
+                           ignore_untracked=ignore_untracked,
+                           paths=paths)
         if out:
             # Get a more helpful error message.
             out = self._status(porcelain=False,
-                               ignore_untracked=ignore_untracked)
+                               ignore_untracked=ignore_untracked,
+                               paths=paths)
             return (False, "".join(out))
         else:
             return (True, '')
@@ -1063,6 +1071,24 @@ class GitRepository(object):
             raise KeyError
         return value[0][:-1]  # first line with \n ending removed
 
+    def set_user_name(self, name):
+        """
+        Sets the full name to use for git commits.
+
+        @param name: full name to use
+        """
+        args = GitArgs('user.name', name)
+        self._git_command("config", args.args)
+
+    def set_user_email(self, email):
+        """
+        Sets the email address to use for git commits.
+
+        @param email: email address to use
+        """
+        args = GitArgs('user.email', email)
+        self._git_command("config", args.args)
+
     def get_author_info(self):
         """
         Determine a sane values for author name and author email from git's
@@ -1216,7 +1242,7 @@ class GitRepository(object):
         self._git_command("pull", args.args)
 
     def push(self, repo=None, src=None, dst=None, ff_only=True, force=False,
-             tags=False):
+             tags=False, dry_run=False):
         """
         Push changes to the remote repo
 
@@ -1233,11 +1259,14 @@ class GitRepository(object):
         @type force: C{bool}
         @param tags: push all refs under refs/tags, in addition to other refs
         @type tags: C{bool}
+        @param dry_run: dry run
+        @type dry_run: C{bool}
         """
         args = GitArgs()
         args.add_cond(repo, repo)
         args.add_true(force, "-f")
         args.add_true(tags, "--tags")
+        args.add_true(dry_run, "--dry-run")
 
         # Allow for src == '' to delete dst on the remote
         if src is not None:
@@ -1250,7 +1279,7 @@ class GitRepository(object):
 
         self._git_command("push", args.args)
 
-    def push_tag(self, repo, tag):
+    def push_tag(self, repo, tag, dry_run=False):
         """
         Push a tag to the remote repo
 
@@ -1258,8 +1287,11 @@ class GitRepository(object):
         @type repo: C{str}
         @param tag: the name of the tag
         @type tag: C{str}
+        @param dry_run: dry run
+        @type dry_run: C{bool}
         """
         args = GitArgs(repo, 'tag', tag)
+        args.add_true(dry_run, "--dry-run")
         self._git_command("push", args.args)
 
 #{ Files
@@ -1462,7 +1494,8 @@ class GitRepository(object):
                                   author=author, committer=committer)
         if not commit:
             raise GitRepositoryError("Failed to commit tree")
-        self.update_ref("refs/heads/%s" % branch, commit, cur)
+        self.update_ref("refs/heads/%s" % branch, commit, cur,
+                        msg="gbp: %s" % msg)
         return commit
 
     def commit_tree(self, tree, msg, parents, author={}, committer={}):
@@ -1865,7 +1898,7 @@ class GitRepository(object):
 #{ Repository Creation
 
     @classmethod
-    def create(klass, path, description=None, bare=False):
+    def create(cls, path, description=None, bare=False):
         """
         Create a repository at path
 
@@ -1886,12 +1919,12 @@ class GitRepository(object):
             if not os.path.exists(abspath):
                 os.makedirs(abspath)
             try:
-                stdout, stderr, ret = klass.__git_inout(command='init',
-                                                        args=args.args,
-                                                        input=None,
-                                                        extra_env=None,
-                                                        cwd=abspath,
-                                                        capture_stderr=True)
+                stdout, stderr, ret = cls.__git_inout(command='init',
+                                                      args=args.args,
+                                                      input=None,
+                                                      extra_env=None,
+                                                      cwd=abspath,
+                                                      capture_stderr=True)
             except Exception as excobj:
                 raise GitRepositoryError("Error running git init: %s" % excobj)
             if ret:
@@ -1901,14 +1934,14 @@ class GitRepository(object):
                 with open(os.path.join(abspath, git_dir, "description"), 'w') as f:
                     description += '\n' if description[-1] != '\n' else ''
                     f.write(description)
-            return klass(abspath)
+            return cls(abspath)
         except OSError as err:
             raise GitRepositoryError("Cannot create Git repository at '%s': %s"
                                      % (abspath, err[1]))
         return None
 
     @classmethod
-    def clone(klass, path, remote, depth=0, recursive=False, mirror=False,
+    def clone(cls, path, remote, depth=0, recursive=False, mirror=False,
               bare=False, auto_name=True, reference=None):
         """
         Clone a git repository at I{remote} to I{path}.
@@ -1952,12 +1985,12 @@ class GitRepository(object):
                 os.makedirs(abspath)
 
             try:
-                stdout, stderr, ret = klass.__git_inout(command='clone',
-                                                        args=args.args,
-                                                        input=None,
-                                                        extra_env=None,
-                                                        cwd=abspath,
-                                                        capture_stderr=True)
+                stdout, stderr, ret = cls.__git_inout(command='clone',
+                                                      args=args.args,
+                                                      input=None,
+                                                      extra_env=None,
+                                                      cwd=abspath,
+                                                      capture_stderr=True)
             except Exception as excobj:
                 raise GitRepositoryError("Error running git clone: %s" % excobj)
             if ret:
@@ -1973,7 +2006,7 @@ class GitRepository(object):
                         name = "%s.git" % name
                 elif name.endswith('.git'):
                     name = name[:-4]
-            return klass(os.path.join(abspath, name))
+            return cls(os.path.join(abspath, name))
         except OSError as err:
             raise GitRepositoryError("Cannot clone Git repository "
                                      "'%s' to '%s': %s"
