@@ -167,7 +167,8 @@ def download_orig(url):
 
     try:
         with contextlib.closing(requests.get(url, verify=True, stream=True)) as r:
-            with contextlib.closing(open(target, 'w', CHUNK_SIZE)) as target_fd:
+            r.raise_for_status()
+            with open(target, 'w', CHUNK_SIZE) as target_fd:
                 for d in r.iter_content(CHUNK_SIZE):
                     target_fd.write(d)
     except Exception as e:
