@@ -35,6 +35,7 @@ from gbp.config import (GbpOptionParserDebian, GbpOptionGroup,
                         no_upstream_branch_msg)
 from gbp.errors import GbpError
 from gbp.scripts.common import ExitCodes
+from gbp.scripts.common import repo_setup
 import gbp.log
 
 
@@ -58,7 +59,10 @@ def download_source(pkg, dirs, unauth):
     gbp.log.info("Downloading '%s' using '%s'..." % (pkg, cmd))
 
     gbpc.RunAtCommand(cmd, opts, shell=False)(dir=dirs['download'])
-    dsc = glob.glob(os.path.join(dirs['download'], '*.dsc'))[0]
+    try:
+        dsc = glob.glob(os.path.join(dirs['download'], '*.dsc'))[0]
+    except IndexError:
+        raise GbpError("Did not find a dsc file at %s/" % dirs['download'])
     return dsc
 
 
@@ -235,8 +239,6 @@ def build_parser(name):
     parser.add_config_file_option(option_name="color", dest="color", type='tristate')
     parser.add_config_file_option(option_name="color-scheme",
                                   dest="color_scheme")
-    parser.add_option("--download", action="store_true", dest="download", default=False,
-                      help="download source package")
     branch_group.add_config_file_option(option_name="debian-branch",
                                         dest="debian_branch")
     branch_group.add_config_file_option(option_name="upstream-branch",
@@ -269,6 +271,13 @@ def build_parser(name):
                                                 dest="author_committer_date")
     import_group.add_boolean_config_file_option(option_name="allow-unauthenticated",
                                                 dest="allow_unauthenticated")
+
+    parser.add_config_file_option(option_name="repo-user", dest="repo_user",
+                                  choices=['DEBIAN', 'GIT'])
+    parser.add_config_file_option(option_name="repo-email", dest="repo_email",
+                                  choices=['DEBIAN', 'GIT'])
+    parser.add_option("--download", dest='download', action="store_true",
+                      default=False, help="Ignored. Accepted for compatibility.")
     return parser
 
 
@@ -279,29 +288,65 @@ def parse_args(argv):
 
     (options, args) = parser.parse_args(argv[1:])
     gbp.log.setup(options.color, options.verbose, options.color_scheme)
+
+    if options.download:
+        gbp.log.warn("Passing --download explicitly is deprecated.")
+
     return options, args
 
 
+def is_download(pkg):
+    """
+    >>> is_download("http://foo.example.com/apackage.dsc")
+    (True, 'http://foo.example.com/apackage.dsc')
+    >>> is_download("apt://apackage/sid")
+    (True, 'apackage/sid')
+    >>> is_download("apt_1.0_amd64.dsc")
+    (False, 'apt_1.0_amd64.dsc')
+    >>> is_download("file:///foo/apackage.dsc")
+    (False, '/foo/apackage.dsc')
+    """
+    if pkg.startswith('file://'):
+        return (False, pkg[len('file://'):])
+    elif pkg.startswith('apt://'):
+        return (True, pkg[len('apt://'):])
+    elif re.match("[a-z]{1,5}://", pkg):
+        return (True, pkg)
+    return (False, pkg)
+
+
+def parse_all(argv):
+    options, args = parse_args(argv)
+    if not options:
+        return None, None, None
+
+    if len(args) == 1:
+        pkg = args[0]
+        target = None
+    elif len(args) == 2:
+        pkg = args[0]
+        target = args[1]
+    else:
+        gbp.log.err("Need to give exactly one package to import. Try --help.")
+        return None, None, None
+
+    download, pkg = is_download(pkg)
+    # honor options.download until removed
+    options.download = download or options.download
+    return options, pkg, target
+
+
 def main(argv):
     dirs = dict(top=os.path.abspath(os.curdir))
     needs_repo = False
     ret = 0
     skipped = False
 
-    options, args = parse_args(argv)
+    options, pkg, target = parse_all(argv)
     if not options:
         return ExitCodes.parse_error
 
     try:
-        if len(args) == 1:
-            pkg = args[0]
-            target = None
-        elif len(args) == 2:
-            pkg = args[0]
-            target = args[1]
-        else:
-            gbp.log.err("Need to give exactly one package to import. Try --help.")
-            raise GbpError
         try:
             repo = DebianGitRepository('.')
             is_empty = repo.is_empty()
@@ -337,6 +382,7 @@ def main(argv):
             gbp.log.info("No git repository found, creating one.")
             repo = DebianGitRepository.create(target)
             os.chdir(repo.path)
+            repo_setup.set_user_name_and_email(options.repo_user, options.repo_email, repo)
 
         if repo.bare:
             disable_pristine_tar(options, "Bare repository")
