@@ -18,6 +18,7 @@
 """Import a new upstream version into a Git repository"""
 
 import os
+import re
 import sys
 import tempfile
 import gbp.command_wrappers as gbpc
@@ -85,7 +86,7 @@ class ImportOrigDebianGitRepository(DebianGitRepository):
             try:
                 sha = self.rev_parse(refname)
             except GitRepositoryError as err:
-                gbp.log.warning("Failed to rev-parse %s: %s" % (refname, err))
+                gbp.log.warn("Failed to rev-parse %s: %s" % (refname, err))
         elif action == 'delete':
             pass
         elif action == 'abortmerge':
@@ -461,22 +462,13 @@ def build_parser(name):
     parser.add_option("--uscan", dest='uscan', action="store_true",
                       default=False, help="use uscan(1) to download the new tarball.")
     parser.add_option("--download", dest='download', action="store_true",
-                      default=False, help="Download from URL via http(s).")
+                      default=False, help="Ignored. Accepted for compatibility.")
     return parser
 
 
 def parse_args(argv):
     """Parse the command line arguments
     @return: options and arguments
-
-    # Silence error output
-    >>> _gbp_log_error_bak = gbp.log.error
-    >>> gbp.log.error = lambda x: None
-    >>> parse_args(['arg0', '--download', '--uscan'])
-    (None, None)
-    >>> parse_args(['arg0', '--download', 'first', 'second'])
-    (None, None)
-    >>> gbp.log.error = _gbp_log_error_bak
     """
 
     parser = build_parser(argv[0])
@@ -489,17 +481,27 @@ def parse_args(argv):
     if options.no_dch:
         gbp.log.warn("'--no-dch' passed. This is now the default, please remove this option.")
 
-    if options.uscan and options.download:
-        gbp.log.error("Either uscan or --download can be used, not both.")
-        return None, None
-
-    if options.download and len(args) != 1:
-        gbp.log.error("Need exactly one URL to download not %s" % args)
-        return None, None
+    if options.download:
+        gbp.log.warn("Passing --download explicitly is deprecated.")
 
+    options.download = is_download(args)
     return options, args
 
 
+def is_download(args):
+    """
+    >>> is_download(["http://foo.example.com"])
+    True
+    >>> is_download([])
+    False
+    >>> is_download(["foo-1.1.orig.tar.gz"])
+    False
+    """
+    if args and re.match("https?://", args[0]):
+        return True
+    return False
+
+
 def main(argv):
     ret = 0
     tmpdir = ''
@@ -633,9 +635,9 @@ def main(argv):
                 # Make sure the very last line as an error message
                 gbp.log.err("Rolled back changes after import error.")
             except Exception as e:
-                gbp.log.error("%s" % e)
-                gbp.log.error("Clean up manually and please report a bug: %s" %
-                              repo.rollback_errors)
+                gbp.log.err("%s" % e)
+                gbp.log.err("Clean up manually and please report a bug: %s" %
+                            repo.rollback_errors)
 
     if pristine_orig and linked and not options.symlink_orig:
         os.unlink(pristine_orig)
@@ -647,6 +649,7 @@ def main(argv):
         gbp.log.info("Successfully imported version %s of %s" % (version, source.path))
     return ret
 
+
 if __name__ == "__main__":
     sys.exit(main(sys.argv))
 
