@@ -19,8 +19,9 @@
 import os
 
 from tests.component import (ComponentTestBase,
-                             ComponentTestGitRepository)
-from tests.component.deb import DEB_TEST_DATA_DIR
+                             ComponentTestGitRepository,
+                             skipUnless)
+from tests.component.deb import DEB_TEST_DATA_DIR, DEB_TEST_DOWNLOAD_URL
 
 from nose.tools import ok_, eq_
 
@@ -56,6 +57,33 @@ class TestImportDsc(ComponentTestBase):
         self._check_repo_state(repo, 'master', ['master'])
         assert len(repo.get_commits()) == 3
 
+    @skipUnless(os.getenv("GBP_NETWORK_TESTS"), "network tests disabled")
+    def test_download(self):
+        def _dsc(version):
+            return os.path.join(DEB_TEST_DOWNLOAD_URL,
+                                'dsc-native',
+                                'git-buildpackage_%s.dsc' % version)
+        dsc = _dsc('0.4.14')
+        assert import_dsc(['arg0',
+                           '--allow-unauthenticated',
+                           dsc]) == 0
+        repo = ComponentTestGitRepository('git-buildpackage')
+        self._check_repo_state(repo, 'master', ['master'])
+        assert len(repo.get_commits()) == 1
+
+    @skipUnless(os.getenv("GBP_NETWORK_TESTS"), "network tests disabled")
+    def test_broken_download(self):
+        def _not_a_dsc(version):
+            return os.path.join(DEB_TEST_DOWNLOAD_URL,
+                                'dsc-3.0',
+                                'hello-debhelper_%s.orig.tar.gz' % version)
+
+        f = _not_a_dsc('2.6')
+        assert import_dsc(['arg0',
+                           '--allow-unauthenticated',
+                           f]) == 1
+        self._check_log(-1, "gbp:error: Did not find a dsc file at")
+
     def test_create_branches(self):
         """Test if creating missing branches works"""
         def _dsc(version):
@@ -73,6 +101,9 @@ class TestImportDsc(ComponentTestBase):
         repo = ComponentTestGitRepository('hello-debhelper')
         os.chdir('hello-debhelper')
         assert len(repo.get_commits()) == 2
+        reflog, ret = repo._git_getoutput('reflog')
+        ok_("gbp: Import Debian patch" in reflog[1])
+        ok_("gbp: Import Upstream version 2.6" in reflog[2])
         self._check_repo_state(repo, 'master', ['master', 'pristine-tar', 'upstream'])
         dsc = _dsc('2.8-1')
         assert import_dsc(['arg0',
