@@ -90,6 +90,12 @@ def test_add_files():
     ...                                os.path.join(repo.path, "testfile"))
     >>> repo.is_clean()[0]
     False
+    >>> repo.is_clean('doesnotexist')[0]
+    True
+    >>> repo.is_clean(paths='testfile')[0]
+    False
+    >>> repo.is_clean(paths=['doesnotexist', 'testfile'])[0]
+    False
     >>> repo.is_clean(ignore_untracked=True)[0]
     True
     >>> repo.add_files(repo.path, force=True)
@@ -703,10 +709,12 @@ def test_fetch():
     >>> clone = gbp.git.GitRepository(d)
     >>> clone.fetch()
     >>> clone.push()
+    >>> clone.push('origin', dry_run=True)
     >>> clone.push('origin')
     >>> clone.push('origin', 'master')
     >>> clone.push('origin', 'master', force=True)
     >>> clone.create_tag('tag3')
+    >>> clone.push_tag('origin', 'tag3', True)
     >>> clone.push_tag('origin', 'tag3')
     >>> clone.create_tag('tag4')
     >>> clone.push('origin', 'master', tags=True)
@@ -996,4 +1004,17 @@ def test_cmd_has_feature():
     True
     """
 
+
+def test_set_user_name_and_email():
+    r"""
+    Methods tested:
+        - L{gbp.git.GitRepository.set_user_name}
+        - L{gbp.git.GitRepository.set_user_email}
+
+    >>> import gbp.git
+    >>> repo = gbp.git.GitRepository(dirs['repo'])
+    >>> repo.set_user_name("Michael Stapelberg")
+    >>> repo.set_user_email("stapelberg@test.invalid")
+    """
+
 # vim:et:ts=4:sw=4:et:sts=4:ai:set list listchars=tab\:»·,trail\:·:
